==> boostcrm-widget-1.0.2.tgz: package/es/store/actions/start-call.actions.js <==
import _regeneratorRuntime from 'babel-runtime/regenerator';
import _asyncToGenerator from 'babel-runtime/helpers/asyncToGenerator';
import _isEmpty from 'lodash/isEmpty';
import _isArray from 'lodash/isArray';
import _get from 'lodash/get';
import * as actions from './action-type';
import { createAction } from 'redux-actions';
import { sendMessage } from '../../connections/websocket';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';

import { retryFuncWithFibonancies } from '../../commons/utils';
import webRTC from '../../components/phone-call/webrtc';
import getClientInfo from '../../commons/utils/get-client-info';

export var startCallRequest = createAction(actions.START_CALL + '.REQUEST');
export var startCallSuccess = createAction(actions.START_CALL + '.SUCCESS');
export var startCallError = createAction(actions.START_CALL + '.ERROR');
export var startCall = function startCall(device) {
  return function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, getState) {
      var tenantInfo, _ref2, error, peerConnectionInfo;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return dispatch(startCallRequest({ device: device }));

            case 2:
              tenantInfo = getTenantInfo();

              // Request ICE Server

              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.REQUEST_ICE_SERVERS,
                tenantInfo: tenantInfo
              });
              _context.prev = 4;
              _context.next = 7;
              return retryFuncWithFibonancies(function () {
                // console.log("Trying to connect to server");
                // To test what happen if could not get ice server
                // return false;
                var iceServers = _get(getState(), 'behavior.callInfo.callData.iceServers');
                // console.log("iceServers: ", iceServers);
                var result = _isArray(iceServers) && !_isEmpty(iceServers);
                return result;
              }, [0.5, 1, 2, 3, 5, 8]);

            case 7:
              _context.next = 9;
              return webRTC.startCall(_get(getState(), 'behavior.callInfo.callData.iceServers'));

            case 9:
              _ref2 = _context.sent;
              error = _ref2[0];
              peerConnectionInfo = _ref2[1];

              if (error) {
                _context.next = 26;
                break;
              }

              _context.t0 = sendMessage;
              _context.t1 = GROUP.CALL;
              _context.t2 = TYPE.CALL.START_CALL;
              _context.t3 = peerConnectionInfo;
              _context.next = 19;
              return getClientInfo();

            case 19:
              _context.t4 = _context.sent;
              _context.t5 = {
                peerConnectionInfo: _context.t3,
                callerInfo: _context.t4
              };
              _context.t6 = tenantInfo;
              _context.t7 = {
                group: _context.t1,
                type: _context.t2,
                payload: _context.t5,
                tenantInfo: _context.t6
              };
              (0, _context.t0)(_context.t7);
              _context.next = 28;
              break;

            case 26:
              _context.next = 28;
              return dispatch(startCallError({ error: 'Could not establish the connection' }));

            case 28:
              _context.next = 34;
              break;

            case 30:
              _context.prev = 30;
              _context.t8 = _context['catch'](4);
              _context.next = 34;
              return dispatch(startCallError({ error: 'Could not connect to server' }));

            case 34:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, this, [[4, 30]]);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};

==> boostcrm-widget-1.0.8.tgz: package/es/store/actions/start-call.actions.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _isEmpty from "lodash/isEmpty";
import _isArray from "lodash/isArray";
import _get from "lodash/get";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as actions from './action-type';
import { createAction } from 'redux-actions';
import { sendMessage } from '../../connections/websocket';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';
import { retryFuncWithFibonancies } from '../../commons/utils';
import webRTC from '../../components/phone-call/webrtc';
import getClientInfo from '../../commons/utils/get-client-info';
export var startCallRequest = createAction(actions.START_CALL + ".REQUEST");
export var startCallSuccess = createAction(actions.START_CALL + ".SUCCESS");
export var startCallError = createAction(actions.START_CALL + ".ERROR");
export var startCall = function startCall(device) {
  return /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, getState) {
      var tenantInfo, _yield$webRTC$startCa, error, peerConnectionInfo;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return dispatch(startCallRequest({
                device: device
              }));

            case 2:
              tenantInfo = getTenantInfo(); // Request ICE Server

              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.REQUEST_ICE_SERVERS,
                tenantInfo: tenantInfo
              });
              _context.prev = 4;
              _context.next = 7;
              return retryFuncWithFibonancies(function () {
                // console.log("Trying to connect to server");
                // To test what happen if could not get ice server
                // return false;
                var iceServers = _get(getState(), 'behavior.callInfo.callData.iceServers'); // console.log("iceServers: ", iceServers);


                // console.log("iceServers: ", iceServers);
                var result = _isArray(iceServers) && !_isEmpty(iceServers);
                return result;
              }, [0.5, 1, 2, 3, 5, 8]);

            case 7:
              _context.next = 9;
              return webRTC.startCall(_get(getState(), 'behavior.callInfo.callData.iceServers'));

            case 9:
              _yield$webRTC$startCa = _context.sent;
              error = _yield$webRTC$startCa[0];
              peerConnectionInfo = _yield$webRTC$startCa[1];

              if (error) {
                _context.next = 26;
                break;
              }

              _context.t0 = sendMessage;
              _context.t1 = GROUP.CALL;
              _context.t2 = TYPE.CALL.START_CALL;
              _context.t3 = peerConnectionInfo;
              _context.next = 19;
              return getClientInfo();

            case 19:
              _context.t4 = _context.sent;
              _context.t5 = {
                peerConnectionInfo: _context.t3,
                callerInfo: _context.t4
              };
              _context.t6 = tenantInfo;
              _context.t7 = {
                group: _context.t1,
                type: _context.t2,
                payload: _context.t5,
                tenantInfo: _context.t6
              };
              (0, _context.t0)(_context.t7);
              _context.next = 28;
              break;

            case 26:
              _context.next = 28;
              return dispatch(startCallError({
                error: 'Could not establish the connection'
              }));

            case 28:
              _context.next = 34;
              break;

            case 30:
              _context.prev = 30;
              _context.t8 = _context["catch"](4);
              _context.next = 34;
              return dispatch(startCallError({
                error: 'Could not connect to server'
              }));

            case 34:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[4, 30]]);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};
